@@ -90,7 +90,7 @@ sub parseVdom {
       last;
     }
   }
-} ## end sub parseVdom
+}
 
 sub getZoneFromRoute {
   my ($self, $ipSet) = @_;
@@ -177,13 +177,13 @@ sub parseInterface {
             $interface->{alias} = $+{alias};
           }
 
-        } ## end while ( ( $string = $self...))
+        }
         $self->addElement($interface) if $interface->{vdom} eq $self->{vdom};
-      } ## end if ( $string =~ /edit\s+"(?<name>.+)"/i)
+      }
 
-    } ## end while ( $string = $self->...)
-  } ## end if ( $string =~ /^config system interface/i)
-} ## end sub parseInterface
+    }
+  }
+}
 
 sub addRouteToInterface {
   my $self       = shift;
@@ -263,16 +263,16 @@ sub parseRoute {
           if ($string =~ /set\s+priority\s+(?<priority>\S+)/) {
             $param{priority} = $+{priority};
           }
-        } ## end while ( ( $string = $self...))
+        }
         $param{network} = '0.0.0.0' if not defined $param{network};
         $param{mask}    = 0         if not defined $param{mask};
         next if not defined $param{nextHop};
         my $route = Firewall::Config::Element::Route::Fortinet->new(%param);
         $self->addElement($route);
-      } ## end if ( $string =~ /edit\s+(?<routeId>\d+)/)
-    } ## end while ( $string = $self->...)
-  } ## end if ( $string =~ /(config\s+router\s+static)|(config\s+router\s+policy)/i)
-} ## end sub parseRoute
+      }
+    }
+  }
+}
 
 sub isZone {
   my ($self, $string) = @_;
@@ -314,9 +314,9 @@ sub parseZone {
 
       }
       $self->addElement($zone);
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
-} ## end sub parseZone
+    }
+  }
+}
 
 sub isAddress {
   my ($self, $string) = @_;
@@ -364,7 +364,7 @@ sub parseAddress {
         if ($string =~ /set\s+associated-interface\s+"(?<zone>\S+)"/) {
           $zone = $+{zone};
         }
-      } ## end while ( ( $string = $self...))
+      }
       if ($type eq 'subnet') {
         $ip      = '0.0.0.0' if not defined $ip;
         $mask    = '0'       if not defined $mask;
@@ -390,10 +390,10 @@ sub parseAddress {
       }
       $address->{zone} = $zone if defined $zone;
       $self->addElement($address);
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
+    }
+  }
 
-} ## end sub parseAddress
+}
 
 sub isAddressGroup {
   my ($self, $string) = @_;
@@ -437,10 +437,10 @@ sub parseAddressGroup {
         }
       }
       $self->addElement($addressGroup);
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
+    }
+  }
 
-} ## end sub parseAddressGroup
+}
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
   my ($self, $addrGroupMemberName) = @_;
@@ -497,11 +497,11 @@ sub parseService {
               $service->{config} = $config;
             }
           }
-        } ## end if ( $string =~ /set (?<protocol>tcp|udp)-portrange\s+(?<ports>.+)/)
-      } ## end while ( ( $string = $self...))
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
-} ## end sub parseService
+        }
+      }
+    }
+  }
+}
 
 sub getPreDefinedService {
   my ($self, $srvName) = @_;
@@ -554,9 +554,9 @@ sub parseServiceGroup {
           }
         }
       }
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
-} ## end sub parseServiceGroup
+    }
+  }
+}
 
 sub getServiceOrServiceGroupFromSrvGroupMemberName {
   my ($self, $srvGroupMemberName) = @_;
@@ -616,10 +616,10 @@ sub parseSchedule {
       }
       my $schedule = Firewall::Config::Element::Schedule::Fortinet->new(%param);
       $self->addElement($schedule);
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
+    }
+  }
 
-} ## end sub parseSchedule
+}
 
 sub isNatPool {
   my ($self, $string) = @_;
@@ -662,10 +662,10 @@ sub parseNatPool {
       $param{poolIp} = $startIp . '-' . $endIp;
       my $ippool = Firewall::Config::Element::NatPool::Fortinet->new(%param);
       $self->addElement($ippool);
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
+    }
+  }
 
-} ## end sub parseNatPool
+}
 
 sub isNat {
   my ($self, $string) = @_;
@@ -734,7 +734,7 @@ sub parseNat {
           my $realZone = $self->getZoneFromRoute($range);
           $param{realZone} = $realZone if defined $realZone;
 
-        } ## end if ( $string =~ /set\s+mappedip\s+(")?(?<realIp>\d+\.\d+[^"]+)(")?/i)
+        }
         if ($string =~ /set\s+portforward\s+enable/i) {
           $nattype = 'dynat';
         }
@@ -778,10 +778,10 @@ sub parseNat {
               # $param{realIp}=$ip;
               # push @realIp,$ip;
               #}
-            } ## end if ( $string =~ /edit\s+\d+/)
-          } ## end while ( $string = $self->...)
-        } ## end if ( $string =~ /config\s+realservers/i)
-      } ## end while ( ( $string = $self...))
+            }
+          }
+        }
+      }
       my $nat;
       if ($nattype eq 'stnat') {
         $nat = Firewall::Config::Element::StaticNat::Fortinet->new(%param);
@@ -810,9 +810,9 @@ sub parseNat {
         type     => 'iprange'
       );
       $self->addElement($vip);
-    } ## end if ( $string =~ /edit\s+"(?<name>.+)"/)
-  } ## end while ( $string = $self->...)
-} ## end sub parseNat
+    }
+  }
+}
 
 sub isRule {
   my ($self, $string) = @_;
@@ -895,7 +895,7 @@ sub parseRule {
         if ($string =~ /set\s+poolname\s+"(?<poolname>.+)"/i) {
           $poolname = $+{poolname};
         }
-      } ## end while ( ( $string = $self...))
+      }
       $param{content} = $content;
       my $rule = Firewall::Config::Element::Rule::Fortinet->new(%param);
       $self->addElement($rule);
@@ -950,12 +950,12 @@ sub parseRule {
 
         }
 
-      } ## end if ($natenable)
+      }
 
-    } ## end if ( $string =~ /edit\s+(?<policyId>\d+)/)
-  } ## end while ( $string = $self->...)
+    }
+  }
 
-} ## end sub parseRule
+}
 
 sub addToRuleSrcAddressGroup {
   my ($self, $rule, $srcAddrName) = @_;
@@ -973,7 +973,7 @@ sub addToRuleSrcAddressGroup {
     $self->warn("的 srcAddrName $srcAddrName 不是address 也不是 addressGroup\n");
   }
   $rule->addSrcAddressMembers($srcAddrName, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 sub addToRuleDstAddressGroup {
   my ($self, $rule, $dstAddrName) = @_;
@@ -991,7 +991,7 @@ sub addToRuleDstAddressGroup {
     $self->warn("的 dstAddrName $dstAddrName 不是address 也不是 addressGroup\n");
   }
   $rule->addDstAddressMembers($dstAddrName, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName) = @_;
