@@ -66,7 +66,7 @@ sub parse {
 
   # 清空解析配置，加速内存回收
   $self->{"config"} = "";
-} ## end sub parse
+}
 
 #------------------------------------------------------------------------------
 # isVersion 判断防火墙版本配置代码块
@@ -162,12 +162,12 @@ sub parseInterface {
 
       # 拼接接口代码块
       $config .= "\n" . $string;
-    } ## end while ( $string = $self->...)
+    }
 
     # 返回计算结果
     $interface->{"config"} = $config;
-  } ## end if ( $string =~ /^interface\s+(?<name>\S+)/i)
-} ## end sub parseInterface
+  }
+}
 
 #------------------------------------------------------------------------------
 # isZone 判断防火墙安全区域代码块
@@ -232,8 +232,8 @@ sub parseZone {
 
     # 返回计算结果，每个解析对象都集成角色的config属性
     $zone->{"config"} = $config;
-  } ## end if ( $string =~ /firewall\s+zone\s+(?:name\s+)?(?<name>\S+)/i)
-} ## end sub parseZone
+  }
+}
 
 #------------------------------------------------------------------------------
 # isAddress 判断防火墙地址组代码块
@@ -326,12 +326,12 @@ sub parseAddress {
 
       # 拼接地址组代码块
       $config .= "\n" . $string;
-    } ## end while ( $string = $self->...)
+    }
 
     # 返回计算结果，每个解析对象都集成角色的config属性
     $address->{"config"} = $config;
-  } ## end if ( $string =~ /ip\saddress-set\s(?<name>.*?)\stype\sobject(?:\svpn-instance\s(?<vpn>.*))?/i)
-} ## end sub parseAddress
+  }
+}
 
 #------------------------------------------------------------------------------
 # isAddressGroup 判断防火墙地址组代码块
@@ -424,14 +424,14 @@ sub parseAddressGroup {
 
       # 拼接地址组代码块
       $config .= "\n" . $string;
-    } ## end while ( $string = $self->...)
+    }
 
     # print dumper $address;
 
     # 返回计算结果，每个解析对象都集成角色的config属性
     $address->{"config"} = $config;
-  } ## end if ( $string =~ /ip\saddress-set\s(?<name>.*?)\stype\sgroup(?:\svpn-instance\s(?<vpn>.*))?/i)
-} ## end sub parseAddressGroup
+  }
+}
 
 #------------------------------------------------------------------------------
 # isService 判断防火墙服务端口组代码块
@@ -509,7 +509,7 @@ sub parseService {
           $service = Firewall::Config::Element::Service::Huawei->new(%params);
           $self->addElement($service);
         }
-      } ## end if ( $string =~ ...)
+      }
 
       # 捕捉到 icmp 协议特殊处理
       elsif ($string =~ /icmp/) {
@@ -537,12 +537,12 @@ sub parseService {
 
       # 拼接服务端口代码块
       $config .= "\n" . $string;
-    } ## end while ( $string = $self->...)
+    }
 
     # 返回计算结果，每个解析对象都集成角色的config属性
     $service->{"config"} = $config;
-  } ## end if ( $string =~ /^ip\s+service-set\s+(?<name>\S+)\s+type\s+object/i)
-} ## end sub parseService
+  }
+}
 
 #------------------------------------------------------------------------------
 # getPreDefinedService 获取防火墙预定义服务端口信息
@@ -616,12 +616,12 @@ sub parseServiceGroup {
 
       # 拼接服务端口组代码块
       $config .= "\n" . $string;
-    } ## end while ( $string = $self->...)
+    }
 
     # 返回计算结果，每个解析对象都集成角色的config属性
     $serGroup->{"config"} = $config;
-  } ## end if ( $string =~ /ip\sservice-set\s(?<name>\S+)\stype\sgroup/i)
-} ## end sub parseServiceGroup
+  }
+}
 
 #------------------------------------------------------------------------------
 # getServiceOrServiceGroupFromSrvGroupMemberName 获取服务端口组成员信息
@@ -712,12 +712,12 @@ sub parseSchedule {
 
       # 拼接时间调度代码块
       $config .= "\n" . $string;
-    } ## end while ( $string = $self->...)
+    }
 
     # 返回计算结果，每个解析对象都集成角色的config属性
     $schedule->{"config"} = $config;
-  } ## end if ( $string =~ /time-range\s+(?<name>\S+)/i)
-} ## end sub parseSchedule
+  }
+}
 
 #------------------------------------------------------------------------------
 # isRoute 判断防火墙路由代码块
@@ -787,7 +787,7 @@ sub parseRoute {
   else {
     $self->warn("can't parse route " . $string);
   }
-} ## end sub parseRoute
+}
 
 #------------------------------------------------------------------------------
 # isNatPool 判断防火墙 NatPool 代码块
@@ -871,13 +871,13 @@ sub parseNatPool {
 
     # 拼接 NatPool 代码块
     $params{config} .= "\n" . $string;
-  } ## end while ( $string = $self->...)
+  }
 
   # 实例化 NatPool 对象
   $params{"poolIp"} = \@poolIp;
   my $natPool = Firewall::Config::Element::NatPool::Huawei->new(%params);
   $self->addElement($natPool);
-} ## end sub parseNatPool
+}
 
 #------------------------------------------------------------------------------
 # isNat 判断防火墙 Nat 代码块
@@ -975,7 +975,7 @@ sub parseNat {
               my $srcSet = Firewall::Utils::Ip->getRangeFromIpRange($ipMin, $ipMax);
               $dynamicNat->{"srcIpRange"}->mergeToSet($srcSet);
             }
-          } ## end elsif ( $string =~ ...)
+          }
 
           # 匹配源地址nat
           elsif ($string =~ /action\s+(source-nat|nat)\s+address-group\s+(?<pool>.*)/ox) {
@@ -1032,7 +1032,7 @@ sub parseNat {
               my $dstSet = Firewall::Utils::Ip->getRangeFromIpRange($ipMin, $ipMax);
               $dynamicNat->{"natDstIpRange"}->mergeToSet($dstSet);
             }
-          } ## end elsif ( $string =~ ...)
+          }
 
           # 匹配目的地址nat
           elsif ($string
@@ -1059,7 +1059,7 @@ sub parseNat {
               $dynamicNat->{"dstPort"}  = $+{port};
               $dynamicNat->{"srvRange"} = Firewall::Utils::Ip->getRangeFromService("tcp/$+{port}");
             }
-          } ## end elsif ( $string =~ ...)
+          }
 
           # 目的地址静态na
           elsif ($string
@@ -1088,7 +1088,7 @@ sub parseNat {
               $dynamicNat->{"dstPort"}  = $+{port};
               $dynamicNat->{"srvRange"} = Firewall::Utils::Ip->getRangeFromService("tcp/$+{port}");
             }
-          } ## end elsif ( $string =~ ...)
+          }
 
           # 目的地址pat
           elsif ($string
@@ -1117,13 +1117,13 @@ sub parseNat {
               $dynamicNat->{dstPort}    = $+{port1} . "-" . $+{port2};
               $dynamicNat->{"srvRange"} = Firewall::Utils::Ip->getRangeFromService("tcp/$+{port1}-$+{port2}");
             }
-          } ## end elsif ( $string =~ ...)
+          }
 
           # 接口nat -> 出方向
           elsif ($string =~ /egress-interface\s+(?<interface>\S+)/) {
             $dynamicNat->{"natInterface"} = $+{interface};
           }
-        } ## end while ( $string = $self->...)
+        }
       }
       elsif ($string
         =~ /nat\s+server\s+(?<name>\S+)(\s+vpn-instance\s+(?<vpn>\S+))?(\s+zone\s+(?<zone>\S+))?(\s+protocol\s+(?<proto>\S+))?(\s+global\s+(?:(?<ip1>$ipStr)(\s+(?<ip2>$ipStr))?|interface\s+(?<int>\S+))(?:(?<gport1>\d+)(?<gport2>\d+)?)?(\s+inside\s+(?<inIp1>$ipStr)(\s+(?<inip2>$ipStr))?(?:(?<inport1>\d+)(?<inport2>\d+)?)? /iox
@@ -1160,10 +1160,10 @@ sub parseNat {
         $params{"config"} = $string;
         my $dynamicNat = Firewall::Config::Element::DynamicNat::Huawei->new(%params);
         $self->addElement($dynamicNat);
-      } ## end elsif ( $string =~ ...)
-    } ## end while ( $string = $self->...)
-  } ## end if ( $string =~ /^nat-policy|^nat\sserver/i)
-} ## end sub parseNat
+      }
+    }
+  }
+}
 
 #------------------------------------------------------------------------------
 # addRouteToInterface 添加路由到接口 -> rangeIP
@@ -1206,9 +1206,9 @@ sub addRouteToInterface {
           }
         }
       }
-    } ## end if ( $route->type eq 'static')
-  } ## end for my $route ( values ...)
-} ## end sub addRouteToInterface
+    }
+  }
+}
 
 #------------------------------------------------------------------------------
 # addZoneRange 添加路由到接口 -> rangeIP
@@ -1377,7 +1377,7 @@ sub _parseRule {
           $ipaddr .= "/$muskNum";
           $self->addToRuleDstAddressGroup($rule, $ipaddr, "ipmask");
         }
-      } ## end if ( $string =~ ...)
+      }
 
       # 情况3：地址对象为连续ip格式，包括源目地址
       if ($string =~ /(?<srcOrDst>source-address|destination-address)\srange\s(?<iprange>$ipt\s$ipt)/ox) {
@@ -1422,7 +1422,7 @@ sub _parseRule {
 
         # 传递变量给到 addToRuleServiceGroup
         $self->addToRuleServiceGroup($rule, $params);
-      } ## end if ( $string =~ ...)
+      }
 
       # 解析 rule 时间调度
       if ($string =~ /time-range\s(?<sch>\S+)/ox) {
@@ -1440,7 +1440,7 @@ sub _parseRule {
       #     $rule->{isDisable} = 'disable';
       # }
 
-    } ## end while ( $string = $self->...)
+    }
 
     # rule 5元组状态判断，如果没解析到则设置缺省值
     if (not defined $src) {
@@ -1458,8 +1458,8 @@ sub _parseRule {
     if (not defined $toZone) {
       $rule->{toZone} = 'any';
     }
-  } ## end if ( $string =~ /\srule\s+name\s+(?<name>.*)$/i)
-} ## end sub _parseRule
+  }
+}
 
 #------------------------------------------------------------------------------
 # addToRuleSrcAddressGroup 将 obj name 实例化为 rule 下的 srcAddressGroup
@@ -1494,7 +1494,7 @@ sub addToRuleSrcAddressGroup {
     else {
       $self->warn("的 srcAddrName $srcAddrName 不是address 也不是 addressGroup\n");
     }
-  } ## end if ( $type eq 'addr' )
+  }
 
   # 情况2：类型为单个 ip，实例化 ip 对象后加入成员数组
   elsif ($type eq 'ipmask') {
@@ -1512,7 +1512,7 @@ sub addToRuleSrcAddressGroup {
 
   # 将解析到的 源ip 关联到具体规则下
   $rule->addSrcAddressMembers($name, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 #------------------------------------------------------------------------------
 # addToRuleDstAddressGroup 将 obj name 实例化为 rule 下的 dstAddressGroup
@@ -1545,7 +1545,7 @@ sub addToRuleDstAddressGroup {
     else {
       $self->warn("的 dstAddrName $dstAddrName 不是address 也不是 addressGroup\n");
     }
-  } ## end if ( $type eq 'addr' )
+  }
 
   # 情况2：类型为单个 ip，实例化 ip 对象后加入成员数组
   elsif ($type eq 'ip') {
@@ -1563,7 +1563,7 @@ sub addToRuleDstAddressGroup {
 
   # 将解析到的 目的ip 关联到具体规则下
   $rule->addDstAddressMembers($name, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName) = @_;
@@ -1602,7 +1602,7 @@ sub addToRuleServiceGroup {
     # 将解析到的 端口成员 关联到 rule
     $rule->addServiceMembers($srvMember, $serviceGroup);
 
-  } ## end if ( ref $srvName eq "HASH")
+  }
 
   # 情况2：传递过来的 srvName 为标量
   else {
@@ -1615,7 +1615,7 @@ sub addToRuleServiceGroup {
     }
   }
 
-} ## end sub addToRuleServiceGroup
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
