@@ -36,7 +36,7 @@ sub parse {
 
     #elsif ( $self->isActive($string)       ) { $self->setActive($string)         }
     else { $self->ignoreLine }
-  } ## end while ( defined( my $string...))
+  }
   $self->addRouteToInterface;
   $self->addZoneRange;
   $self->goToHeadLine;
@@ -49,7 +49,7 @@ sub parse {
 
   $self->{config} = "";
 
-} ## end sub parse
+}
 
 sub isInterface {
   my ($self, $string) = @_;
@@ -103,9 +103,9 @@ sub parseInterface {
         $interface->addVlan($vlanInt) if defined $vlanInt;
       }
 
-    } ## end while ( $string = $self->...)
-  } ## end if ( $string =~ /^\s*interface\s+ethernet\s+(?<name>\S+)|^\s*vlan\s+(?<vid>\d+)/i)
-} ## end sub parseInterface
+    }
+  }
+}
 
 sub isZone {
   my ($self, $string) = @_;
@@ -156,10 +156,10 @@ sub parseZone {
 
       }
 
-    } ## end while ( defined( $string ...))
-  } ## end if ( $string =~ /^zone\s+(?<name>\S+)/i)
+    }
+  }
 
-} ## end sub parseZone
+}
 
 sub isAddress {
   my ($self, $string) = @_;
@@ -213,8 +213,8 @@ sub parseAddress {
       $self->warn("can't parse address" . $string);
     }
 
-  } ## end if ( $string =~ /object\s+ipaddr\s+(?<name>\S+)\s+(?<ipList>.+)$/i)
-} ## end sub parseAddress
+  }
+}
 
 sub isAddressGroup {
   my ($self, $string) = @_;
@@ -252,7 +252,7 @@ sub parseAddressGroup {
       }
     }
   }
-} ## end sub parseAddressGroup
+}
 
 sub isService {
   my ($self, $string) = @_;
@@ -307,7 +307,7 @@ sub parseService {
     $self->warn("can't parse service" . $string) if $string !~ /service\s+\S+\s+description/;
   }
 
-} ## end sub parseService
+}
 
 sub getPreDefinedService {
   my ($self, $srvName) = @_;
@@ -354,8 +354,8 @@ sub parseServiceGroup {
         $serGroup->addSrvGroupMember($serName, $obj);
       }
     }
-  } ## end if ( $string =~ /object\s+group\s+(?<name>\S+)\s+type\s+service(\s+(?<srvList>\S+))?/i)
-} ## end sub parseServiceGroup
+  }
+}
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
   my ($self, $addrGroupMemberName) = @_;
@@ -430,7 +430,7 @@ sub parseRoute {
           my $address = $self->getAddressOrAddressGroupFromAddrGroupMemberName($objAddr);
           $params{srcRange} = $address->range if defined $address;
         }
-      } ## end if ( $string =~ ...)
+      }
 
       if (
         $string =~ /route\s+(?<network>\d+\.\d+\S+)\s+(?<mask>\S+)
@@ -450,10 +450,10 @@ sub parseRoute {
 
       }
 
-    } ## end while ( defined( $string ...))
+    }
 
-  } ## end elsif ( $string =~ /policy\s+route\s+(?<name>\S+)/)
-} ## end sub parseRoute
+  }
+}
 
 sub isStaticNat {
   my ($self, $string) = @_;
@@ -564,18 +564,18 @@ sub parseStaticNat {
               my $obj   = Firewall::Config::Element::Service::Neteye->new(srvName => $name, protocol => $proto, dstPort => '0');
               $rule->addServiceMembers($name, $obj);
             }
-          } ## end if ( defined $other )
+          }
 
         }
         else {
           last;
         }
 
-      } ## end if ( $string =~ /policy\s+mip\s+(?<name>\S+)\s+matching\s+(?: ))
-    } ## end while ( defined( $string ...))
+      }
+    }
     $staticnat->{matchRule} = $rule;
-  } ## end if ( $string =~ ...)
-} ## end sub parseStaticNat
+  }
+}
 
 sub isDynamicNat {
   my ($self, $string) = @_;
@@ -765,15 +765,15 @@ sub parseDynamicNat {
               my $obj   = Firewall::Config::Element::Service::Neteye->new(srvName => $name, protocol => $proto, dstPort => '0');
               $rule->addServiceMembers($name, $obj);
             }
-          } ## end if ( defined $other )
+          }
 
         }
         else {
           last;
         }
-      } ## end if ( $string =~ /policy\s+(?<type>snat|dnat)\s+(?<name>\S+)\s+matching\s+(?: ))
+      }
 
-    } ## end while ( defined( $string ...))
+    }
     if ($useMatchRule == 1) {
       $dynamicNat->{matchRule} = $rule;
       if ($dynamicNat->{natDirection} eq 'source') {
@@ -784,8 +784,8 @@ sub parseDynamicNat {
         $dynamicNat->{srcIpRange} = $rule->srcAddressGroup->range;
       }
     }
-  } ## end if ( $string =~ /policy\s+(?<nattype>snat|dnat)\s+(?<name>\S+)\s+(?: ))
-} ## end sub parseDynamicNat
+  }
+}
 
 sub addRouteToInterface {
   my $self       = shift;
@@ -813,10 +813,10 @@ sub addRouteToInterface {
         }
 
       }
-    } ## end if ( $route->type eq 'static')
-  } ## end for my $route ( values ...)
+    }
+  }
 
-} ## end sub addRouteToInterface
+}
 
 sub addZoneRange {
   my $self = shift;
@@ -1040,8 +1040,8 @@ sub parseRule {
     if (defined $serObjg) {
       $self->addToRuleServiceGroup($rule, $serObjg, 'obj');
     }
-  } ## end elsif ( $string =~ /policy\s+access\s+(?<name>\S+)\s+protocol\s+ )
-} ## end sub parseRule
+  }
+}
 
 sub addToRuleSrcAddressGroup {
   my ($self, $rule, $srcAddrName, $type) = @_;
@@ -1074,7 +1074,7 @@ sub addToRuleSrcAddressGroup {
   }
 
   $rule->addSrcAddressMembers($name, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 sub addToRuleDstAddressGroup {
   my ($self, $rule, $dstAddrName, $type) = @_;
@@ -1107,7 +1107,7 @@ sub addToRuleDstAddressGroup {
     $obj->addMember({range => "$dstAddrName"});
   }
   $rule->addDstAddressMembers($name, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName, $type) = @_;
@@ -1131,7 +1131,7 @@ sub addToRuleServiceGroup {
     $rule->addServiceMembers($srvName, $obj);
 
   }
-} ## end sub addToRuleServiceGroup
+}
 
 sub getInterfaceFromRoute {
   my ($self, $srcSet, $dstSet) = @_;
@@ -1148,7 +1148,7 @@ sub getInterfaceFromRoute {
   }
   return;
 
-} ## end sub getInterfaceFromRoute
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
