@@ -59,7 +59,7 @@ sub parse {
     elsif ($self->isRule($string)) { $self->parseRule($string) }
     else                           { $self->ignoreLine }
   }
-} ## end sub parse
+}
 
 sub isInterface {
   my ($self, $string) = @_;
@@ -132,8 +132,8 @@ sub parseInterface {
     else {
       $self->warn("interface $string 分析不出来\n");
     }
-  } ## end while ( $string = $self->...)
-} ## end sub parseInterface
+  }
+}
 
 sub addInterfaceVlan {
   my $self       = shift;
@@ -154,7 +154,7 @@ sub addInterfaceVlan {
       }
     }
   }
-} ## end sub addInterfaceVlan
+}
 
 sub isRoute {
   my ($self, $string) = @_;
@@ -201,8 +201,8 @@ sub parseRoute {
     else {
       $self->warn("route $string 分析不出来\n");
     }
-  } ## end while ( $string = $self->...)
-} ## end sub parseRoute
+  }
+}
 
 sub isZone {
   my ($self, $string) = @_;
@@ -242,8 +242,8 @@ sub parseZone {
     else {
       $self->warn("zone $string 分析不出来\n");
     }
-  } ## end while ( $string = $self->...)
-} ## end sub parseZone
+  }
+}
 
 sub addZoneNameToVlanInt {
   my $self       = shift;
@@ -280,7 +280,7 @@ sub addRouteToInterface {
       }
     }
   }
-} ## end sub addRouteToInterface
+}
 
 sub addZoneRange {
   my $self = shift;
@@ -345,7 +345,7 @@ sub parseAddress {
   else {
     $self->warn("address $string 分析不出来\n");
   }
-} ## end sub parseAddress
+}
 
 sub isAddressGroup {
   my ($self, $string) = @_;
@@ -389,7 +389,7 @@ sub parseAddressGroup {
   else {
     $self->warn("addressGroup $string 分析不出来\n");
   }
-} ## end sub parseAddressGroup
+}
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
   my ($self, $addName) = @_;
@@ -439,7 +439,7 @@ sub parseService {
   else {
     $self->warn("service $string 分析不出来\n");
   }
-} ## end sub parseService
+}
 
 sub getPreDefinedService {
   my ($self, $srvName) = @_;
@@ -485,7 +485,7 @@ sub parseServiceGroup {
   else {
     $self->warn("serviceGroup $string can't parser");
   }
-} ## end sub parseServiceGroup
+}
 
 sub getServiceOrServiceGroupFromSrvGroupMemberName {
   my ($self, $srvGroupMemberName) = @_;
@@ -547,7 +547,7 @@ sub parseSchedule {
   else {
     $self->warn("Schedule $string 分析不出来\n");
   }
-} ## end sub parseSchedule
+}
 
 sub isNat {
   my ($self, $string) = @_;
@@ -654,7 +654,7 @@ sub parseNat {
           $param{natSrcIpRange}->mergeToSet($address->range) if defined $address;
         }
       }
-    } ## end if ( defined $+{natsrc...})
+    }
     if (defined $+{natdst}) {
       $param{natDirection}  = 'destination';
       $param{natDstIpRange} = Firewall::Utils::Set->new;
@@ -677,7 +677,7 @@ sub parseNat {
           $param{natDstIpRange}->mergeToSet($address->range) if defined $address;
         }
       }
-    } ## end if ( defined $+{natdst...})
+    }
     if (defined $+{natsrv}) {
       my $service = $self->getService($+{natsrv});
       $param{natSrvRange} = $service->range;
@@ -700,7 +700,7 @@ sub parseNat {
   else {
     $self->warn("nat $string 分析不出来\n");
   }
-} ## end sub parseNat
+}
 
 sub getvlanarea {
   my ($self, $vlanName) = @_;
@@ -845,7 +845,7 @@ sub parseRule {
   else {
     $self->warn("rule $string 分析不出来\n");
   }
-} ## end sub parseRule
+}
 
 sub addToRuleSrcAddressGroup {
   my ($self, $rule, $srcAddrName, $type) = @_;
@@ -872,7 +872,7 @@ sub addToRuleSrcAddressGroup {
     $self->warn("的 srcAddrName $srcAddrName 不是address 也不是 addressGroup\n");
   }
   $rule->addSrcAddressMembers($srcAddrName, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 sub addToRuleDstAddressGroup {
   my ($self, $rule, $dstAddrName, $type) = @_;
@@ -899,7 +899,7 @@ sub addToRuleDstAddressGroup {
     $self->warn("的 dstAddrName $dstAddrName 不是address 也不是 addressGroup\n");
   }
   $rule->addDstAddressMembers($dstAddrName, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName) = @_;
